@@ -23,8 +23,6 @@ class AtlantisClient:
 
     @property
     def client_secret(self):
-        if self._client_secret is None:
-            raise InvalidInitParameters('invalid initialization of the required parameters.')
         return self._client_secret
 
     def issue_token(self, code, redirect_uri):
@@ -102,11 +100,13 @@ class AtlantisClient:
         except Exception as err:
             raise InvalidTokenError(err)
 
-    def introspect_token(self, access_token):
+    def introspect_token(self, access_token, raise_for_inactive=True):
         """Verifica se o access_token está válido
 
         :param access_token: Token do usuário gerado pelo Atlantis
         :type access_token: str
+        :param raise_for_inactive: Retorna um erro caso o token esteja inativo, valor padrão `True`
+        :type access_token: bool, opcional
         :return: Retorna dados do token: ``active``, ``email``, ``scope``, ``client_id``, ``exp``, etc..
         :rtype: dict
         """
@@ -119,7 +119,13 @@ class AtlantisClient:
                 'client_secret': self.client_secret
             })
         response.raise_for_status()
-        return response.json()
+
+        json = response.json()
+
+        if raise_for_inactive and json['active'] is False:
+            raise InvalidTokenError('Inactive token')
+
+        return json
 
     def introspect_api_key(self, api_key):
         """Verifica se a Api key é válida
@@ -151,7 +157,7 @@ class AtlantisClientFlask(AtlantisClient):
     def init_app(self, app):
         self.atlantis_url = app.config['ATLANTIS_URL']
         self._client_id = app.config['ATLANTIS_CLIENT_ID']
-        self._client_secret = app.config['ATLANTIS_CLIENT_SECRET']
+        self._client_secret = app.config.get('ATLANTIS_CLIENT_SECRET')
 
 
 class InvalidTokenError(RuntimeError):
